class Ecu_Query:
    get_ecu_query = """
        query GetECUData($input: ECUFilterArgs) {
            ecu(input: $input) {
                id
                code
                name
            }
        }
    """



import unittest
from wivi_graph_client_py.client import GraphQL_Client
from datetime import datetime

client = GraphQL_Client("http://localhost:8092/graphql")

class TestUpsertSignalData(unittest.IsolatedAsyncioTestCase):
    async def setUp(self):
        self.configuration = {
            "input": {
                "deviceId": 1,
                "fleetId": 1,
                "organizationId": 1,
                "vehicleId": 1
            }
        }
        self.messages = {
            "input": {
                "messages": [
                    {
                        "arbId": "67890",
                        "name": "example_name",
                        "networkName": "PS-011",
                        "ecuId": "example_network_name",
                        "uploadId": 12345
                    }
                ]
            }
        }
        self.configurationDto = client.create_configuration(self.configuration)
        self.msgDto = (client.create_message(self.messages))
        self.signal_data = [
            {
                "time":  "2024-02-18T12:00:00Z",
                "svalue": "example_svalue",
                "value": 123,
            }
            for _ in range(50)
        ]
        self.signal_data_large = [
            {
                "time":  "2024-02-18T12:00:00Z",
                "svalue": "example_svalue",
                "value": 123,
            }
            for _ in range(50)
        ]

        self.upsert_signal = {
            "configurationId": self.configurationDto['data']['createConfiguration']['id'],
            "messageId": self.msgDto['data']['createMessage'][0]['id'],
            "data": self.signal_data,
            "paramType": "NUMBER",
            "signalType": "SIGNAL",
            "unit": "km/h",
            "name": "example_name"
        }
        self.upsert_signal_large = {
            "configurationId": self.configurationDto['data']['createConfiguration']['id'],
            "messageId": self.msgDto['data']['createMessage'][0]['id'],
            "data": self.signal_data_large,
            "paramType": "NUMBER",
            "signalType": "SIGNAL",
            "unit": "km/h",
            "name": "example_name"
        }

        self.upsert_signal_data_input = {
            "signals": [self.upsert_signal for _ in range(5)]
        }
        
        self.upsert_signal_data_input_large = {
            "signals": [self.upsert_signal for _ in range(5)]
        }

    async def test_simple(self):
        await self.setUp()
        signal_data_payload = {
            "input": self.upsert_signal_data_input
        }
        response = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertEqual(len(result), 5)  # Ensure 5 signals were upserted
        first_signal = result[0]
        self.assertEqual(first_signal['configurationId'], self.configurationDto['data']['createConfiguration']['id'])
        self.assertEqual(first_signal['messageId'], self.msgDto['data']['createMessage'][0]['id'])


    async def test_upsert(self):
        await self.setUp()
        signal_data_payload = {
            "input": self.upsert_signal_data_input
        }
        response = client.upsert_signal_data(signal_data_payload)
        response2 = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        result2 = response2.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertIsInstance(result2, list)
        self.assertEqual(result[0]['configurationId'], result2[0]['configurationId'])
        self.assertEqual(result[0]['messageId'], result2[0]['messageId'])
        self.assertEqual(result[0]['name'], result2[0]['name'])
        self.assertEqual(result[0]['unit'], result2[0]['unit'])
        self.assertEqual(result[0]['paramType'], result2[0]['paramType'])


    async def test_should_upsert_really_large_payload(self):
        await self.setUp()
        signal_data_payload = {
            "input": self.upsert_signal_data_input_large
        }
        response = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertEqual(result[0]['configurationId'], self.configurationDto['data']['createConfiguration']['id'])
        self.assertEqual(result[0]['messageId'], self.msgDto['data']['createMessage'][0]['id'])

    async def test_can_insert_DID(self):
        await self.setUp()
        signal_data_payload = {
            "input":{
                "signals": [
                    {
                        "configurationId": self.configurationDto['data']['createConfiguration']['id'],
                        "messageId": self.msgDto['data']['createMessage'][0]['id'],
                        "data": self.signal_data,
                        "paramType": "NUMBER",
                        "signalType": "DID",
                        "unit": "km/h",
                        "name": "example_name"
                    }
                ]
            }
        }
        response = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertEqual(result[0]['configurationId'], self.configurationDto['data']['createConfiguration']['id'])
        self.assertEqual(result[0]['messageId'], self.msgDto['data']['createMessage'][0]['id'])

    async def test_can_insert_DMR(self):
        await self.setUp()
        signal_data_payload = {
            "input":{
                "signals": [
                    {
                        "configurationId": self.configurationDto['data']['createConfiguration']['id'],
                        "messageId": self.msgDto['data']['createMessage'][0]['id'],
                        "data": self.signal_data,
                        "paramType": "NUMBER",
                        "signalType": "DMR",
                        "unit": "km/h",
                        "name": "example_name"
                    }
                ]
            }
        }
        response = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertEqual(result[0]['configurationId'], self.configurationDto['data']['createConfiguration']['id'])
        self.assertEqual(result[0]['messageId'], self.msgDto['data']['createMessage'][0]['id'])

    async def test_can_insert_PID(self):
        await self.setUp()
        signal_data_payload = {
            "input":{
                "signals": [
                    {
                        "configurationId": self.configurationDto['data']['createConfiguration']['id'],
                        "messageId": self.msgDto['data']['createMessage'][0]['id'],
                        "data": self.signal_data,
                        "paramType": "NUMBER",
                        "signalType": "PID",
                        "unit": "km/h",
                        "name": "example_name"
                    }
                ]
            }
        }
        response = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertEqual(result[0]['configurationId'], self.configurationDto['data']['createConfiguration']['id'])
        self.assertEqual(result[0]['messageId'], self.msgDto['data']['createMessage'][0]['id'])

    async def test_can_insert_SIGNAL(self):
        await self.setUp()
        signal_data_payload = {
            "input":{
                "signals": [
                    {
                        "configurationId": self.configurationDto['data']['createConfiguration']['id'],
                        "messageId": self.msgDto['data']['createMessage'][0]['id'],
                        "data": self.signal_data,
                        "paramType": "NUMBER",
                        "signalType": "SIGNAL",
                        "unit": "km/h",
                        "name": "example_name"
                    }
                ]
            }
        }
        response = client.upsert_signal_data(signal_data_payload)
        result = response.get('data', {}).get('upsertSignalData', [])
        self.assertIsInstance(result, list)
        self.assertEqual(result[0]['configurationId'], self.configurationDto['data']['createConfiguration']['id'])
        self.assertEqual(result[0]['messageId'], self.msgDto['data']['createMessage'][0]['id'])

if __name__ == "__main__":
    unittest.main()



class Device_Info_Query:
    get_device_info_query = """
        query GetDeviceInfo($input: DeviceInfoFilterInput) {
            deviceInfo(input: $input) {
                vehicleId
                deviceInfoData {
                    name
                    data {
                        time
                        svalue
                        value
                    }
                }
            }
        }
    """

class Device_Info_Mutation:
    create_device_info_mutation = '''
        mutation CreateDeviceStatus($input: CreateDeviceStatusInput) {
            CreateDeviceStatus(input: $input) {
                configurationId
            }
        }
    '''

    delete_device_info_mutation = '''
        mutation deleteDeviceStatus($input: DeleteDeviceStatusInput) {
            deleteDeviceInfo(input: $input) {
                configurations
        }
    '''



import unittest
from faker import Faker
from wivi_graph_client_py.client import GraphQL_Client

class TestCreateFailedProcessing(unittest.TestCase):
    def setUp(self):
        self.fake = Faker()
        self.client = GraphQL_Client("http://localhost:8092/graphql")
        self.configurationDto = None

        # Create a configuration and store its DTO for later use
        configuration = {
            "vehicleId": self.fake.random_int(),
            "fleetId": self.fake.random_int(),
            "organizationId": self.fake.random_int(),
            "deviceId": self.fake.random_int()
        }
        response = self.client.create_configuration({"input": configuration})
        self.configurationDto = response.get('data', {}).get('createConfiguration', {}).get('configuration', {})

    async def test_basic(self):
        await self.setUp()
        print(self.configurationDto)
        failed_processing = {
            "configuration": {
                "deviceId": self.configurationDto.get('deviceId'),
                "fleetId": self.configurationDto.get('fleetId'),
                "organizationId": self.configurationDto.get('organizationId'),
                "vehicleId": self.configurationDto.get('vehicleId')
            },
            "dbExists": self.fake.boolean(),
            "pipelineStatus": self.fake.random_element(["FINISHED", "STARTED", "NEW","CANCELLED","LATER","ERROR","NOT_FOUND"]),
            "uploadId": self.fake.random_int(),
            "xmlExists": self.fake.boolean()
        }
        response = self.client.upsert_failed_processing({"input": failed_processing})
        print(response)
        results = response.get('data', {}).get('upsertFailedProcessing', {})

        self.assertIsInstance(results, dict)
        self.assertIsInstance(results.get('configuration'), dict)
        self.assertEqual(results['configuration']['deviceId'], failed_processing['configuration']['deviceId'])
        self.assertEqual(results['configuration']['fleetId'], failed_processing['configuration']['fleetId'])
        self.assertEqual(results['configuration']['organizationId'], failed_processing['configuration']['organizationId'])
        self.assertEqual(results['configuration']['vehicleId'], failed_processing['configuration']['vehicleId'])
        self.assertIsInstance(results.get('dbExists'), bool)
        self.assertIsInstance(results.get('pipelineStatus'), str)
        self.assertIsInstance(results.get('uploadId'), str)
        self.assertIsInstance(results.get('xmlExists'), bool)

if __name__ == "__main__":
    unittest.main()



class Network_Stats_Query:
    get_network_stats_query = """
        query networkStatusQuery($input: NetworkStatsFilterInput) {
            networkStats(input: $input) {
                errorMessages
                longMessageParts
                matchedMessages
                maxTime
                minTime
                name
                uploadId
                vehicleId
                unmatchedMessages
                totalMessages
            }
        }
    """

class Network_Stats_Mutation:
    create_network_stats_mutation = """
        mutation createNetworkStats($input: CreateNetworkStatsInput!) {
            createNetworkStats(input: $input) {
                name
                vehicleId
                uploadId
                totalMessages
                matchedMessages
                unmatchedMessages
                errorMessages
                longMessageParts
                minTime
                maxTime
                rate
            }
        }
    """



class Device_Status_Query:
    get_device_status_query = """
        query GetDeviceStatus($input: DeviceStatusFilterInput) {
            DeviceStatus(input: $input) {
                vehicleId
                DeviceStatusData {
                    name
                    data {
                        time
                        svalue
                        value
                    }
                }
            }
        }
    """

class Device_Status_Mutation:
    create_device_status_mutation = '''
        mutation createDeviceStatus($input: CreateDeviceStatusInput) {
            createDeviceStatus(input: $input) {
                configuration {
                    deviceId
                    vehicleId
                    organizationId
                    fleetId
                }
            }
        }
    '''

    delete_device_status_mutation = '''
        mutation DeleteDeviceStatus($input: DeleteDeviceStatusInput) {
            deleteDeviceStatus(input: $input) {
                configurations
            }
        }
    '''



import unittest
from wivi_graph_client_py.client import GraphQL_Client
from datetime import datetime

client = GraphQL_Client("http://localhost:8092/graphql")

class TestUpsertGpsData(unittest.IsolatedAsyncioTestCase):
    async def setUp(self):
        self.configuration = {
            "input": {
                "deviceId": 1,
                "fleetId": 1,
                "organizationId": 1,
                "vehicleId": 1
            }
        } 
        self.configurationDto = client.create_configuration(self.configuration)
        self.gps_data = {
            "time": datetime.utcnow().isoformat(),
            "accuracy": 10,
            "altitude": 100,
            "latitude": 37.7749,
            "longitude": -122.4194,
            "bearing": "North",
            "speed": 50,
            "available": {
                "accuracy": True,
                "time": True,
                "date": True,
                "latlon": True,
                "speed": True,
                "altitude": True,
                "bearing": True
            }
        }
        self.upsert_gps_data_input = {
            "configurationId": self.configurationDto['data']['createConfiguration']['id'],
            "data": [self.gps_data]
        }
    
    async def test_create(self):
        await self.setUp()
        result = client.upsert_gps({"input": self.upsert_gps_data_input})
        upserted_data = result.get('data', {}).get('upsertGpsData', {})
        config_data = self.configurationDto.get('data', {}).get('createConfiguration', {})
        
        self.assertIsInstance(upserted_data, dict)
        self.assertIsInstance(upserted_data.get('id'), int)
        self.assertEqual(upserted_data.get('deviceId'), config_data.get('deviceId'))
        self.assertEqual(upserted_data.get('vehicleId'), config_data.get('vehicleId'))
        self.assertEqual(upserted_data.get('organizationId'), config_data.get('organizationId'))
        self.assertEqual(upserted_data.get('fleetId'), config_data.get('fleetId'))

if __name__ == "__main__":
    unittest.main()



class Dtc_Query:
    get_dtc_query = """
        query dtcData($input: DtcDataFilterInput) {
            dtcData(input: $input) {
                vehicleId
                dtcs {
                    messageName
                    description
                    uploadId
                    domain
                    code
                    status
                    dtcId
                    count
                    failure
                    occurances {
                        time
                        state
                        snapshots {
                            time
                            bytes
                        }
                        extensions {
                            time
                            bytes
                        }
                    }
                }
            }
        }
    """

class Dtc_Mutation:
    upsert_dtc_mutation = """
        mutation UpsertDtcData($input: [UpsertDtcDataInput]) {
            upsertDtcData(input: $input) {
                configurationId
                messageId
            }
        }
    """

    delete_dtc_mutation = """
        mutation DeleteDtcData($input: DeleteDtcDataInput) {
            deleteDtcData(input: $input) {
                configurations
            }
        }
    """



class Configuration_Query:
    get_configuration_query = """
        query configurations($input: ConfigurationFilterInput) {
            configuration(input: $input) {
                id
                deviceId
                fleetId
                organizationId
                vehicleId
            }
        }
    """
    configurationsMetaQuery = """
        query configurations($input: ConfigurationFilterInput) {
            configuration(input: $input) {
                id
                deviceId
                fleetId
                organizationId
                vehicleId
                signals {
                    name
                }
                ecus {
                    name
                }
                messages {
                    name
                }
                network {
                    name
                }
            }
        }
    """
class Configuration_Mutation:
    create_configuration_mutation = """
        mutation createConfiguration($input: CreateConfigurationInput!) {
            createConfiguration(input: $input) {
                id
                deviceId
                vehicleId
                organizationId
                fleetId
            }
        }
    """



from client import GraphQL_Client

if __name__ == "__main__":
    endpoint = "http://0.0.0.0:8080/graphql"

    client = GraphQL_Client(endpoint)
    variables = {
        "input": {
            "configurationId": 3,
            "info": [
                {
                    "time": "2022-10-09T00:00:00Z",
                    "stats": [
                        {"name": "DevInfoTest", "svalue": "100Km/h", "value": 100}
                    ],
                }
            ],
        }
    }
    response = client.create_device_info(variables)





import unittest
from faker import Faker
from wivi_graph_client_py.client import GraphQL_Client

class TestCreateMessage(unittest.TestCase):
    def setUp(self):
        self.fake = Faker()
        self.client = GraphQL_Client("http://localhost:8092/graphql")
        self.messages = {
            "messages": [{
                "uploadId": self.fake.random_int(),
                "networkName": str(self.fake.random_number(digits=3)),
                "ecuId": self.fake.word(),
                "name": self.fake.word(),
                "requestCode": self.fake.word(),
                "arbId": str(self.fake.random_number(digits=3))
            }]
        }

    def test_simple(self):
        response = self.client.create_message({"input": self.messages})
        results = response.get('data', {}).get('createMessage', [])

        self.assertIsInstance(results, list)

    def test_idempotent(self):
        response = self.client.create_message({"input": self.messages})
        results = response.get('data', {}).get('createMessage', [])

        response2 = self.client.create_message({"input": self.messages})
        results2 = response2.get('data', {}).get('createMessage', [])
        self.assertIsInstance(results, list)
        self.assertIsInstance(results2, list)
        self.assertEqual(results[0]['id'], results2[0]['id'])

    def test_idempotent_across_arbId(self):
        self.messages['messages'][0]['arbId'] = None  # Set arbId to None to simulate missing value
        response = self.client.create_message({"input": self.messages})
        results = response.get('data', {}).get('createMessage', [])

        response2 = self.client.create_message({"input": self.messages})
        results2 = response2.get('data', {}).get('createMessage', [])

        self.assertIsInstance(results, list)
        self.assertIsInstance(results2, list)
        self.assertEqual(results[0]['id'], results2[0]['id'])

if __name__ == "__main__":
    unittest.main()



class Signals_Query:
    get_signals_query = """
        query signals($input: SignalFilterInput) {
            signal(input: $input) {
                name
                unit
                paramType
                paramId
                messageName
                configurationId
                messageId
                networkName
            }
        }
    """

    get_signals_data_query = """
        query signalData($input: SignalDataFilterInput) {
            signalData(input: $input) {
                vehicleId
                name
                time
                value
                svalue
            }
        }
    """

class Signals_Mutation:
    upsert_signal_data_mutation = """
        mutation UpsertSignalData($input: UpsertSignalDataInput) {
            upsertSignalData(input: $input) {
                configurationId
                messageId
                messageName
                name
                paramType
                unit
            }
        }
    """

    delete_signal_data_mutation = """
        mutation DeleteSignalData($input: DeleteSignalDataInput) {
            deleteSignalData(input: $input) {
               configurations
            }
        }
    """



class GPS_Query:
    get_gps_query = """
        query GpsDataByVehicle($input: GpsDataFilterInput) {
            GpsDataByVehicle(input: $input) {
                vehicleId
                gpsData {
                    time
                    latitude
                    longitude
                    accuracy
                    altitude
                }
            }
        }
"""

class GPS_Mutation:
    upsert_gps_mutation = """
        mutation UpsertGpsData($input: UpsertGpsDataInput) {
            upsertGpsData(input: $input) {
                deviceId
                fleetId
                vehicleId
                id
                organizationId
            }
        }
    """

    delete_gps_mutation = '''
        mutation DeleteGPSData($input: DeleteGPSDataInput) {
            deleteGpsData(input: $input) {
               
            }
        }
    '''



class Formula_Query:
    load_formula_query = """
        query LoadFormula($input: LoadFormulaArgs) {
            formula(input: $input) {
                id
                name
                source
                unit
                time
                formula
                fun
            }
        }
    """

    calculate_formula_query = '''
        query CalculateFormula($input: CalculateFormulaArgs) {
            calculateFormula(input: $input) {
                vehicleId
                data {
                    value
                    time
                }
            }
        }
    '''

class Formula_Mutation:
    upsert_formula_mutation = """
        mutation UpsertFormula($input: UpsertFormulaInput) {
            upsertFormula(input: $input) {
                id
                name
                source
                unit
                time
                formula
            }
        }
    """

    upsert_formula_constant_mutation = """
        mutation UpsertFormulaConstant($input: UpsertFormulaConstantInput) {
            upsertFormulaConstant(input: $input) {
                id
                name
                value
            }
        }
    """




class Device_Version_Query:
    get_device_version_query = """
        query deviceVersion($input: DeviceVersionFilterInput) {
            deviceVersion(input: $input) {
                vehicleId
                deviceVersion {
                    name
                    time
                    value
                }
            }
        }
    """
class Device_Version_Mutation:
    upsert_device_version_mutation = '''
        mutation UpsertDeviceVersion($input: UpsertDeviceVersionInput) {
            upsertDeviceVersion(input: $input) {
                configurationId
            }
        }
    '''

    delete_device_version_mutation = '''
        mutation DeleteDeviceVersion($input: DeleteDeviceVersionInput) {
            deleteDeviceVersion(input: $input) {
                configurations
            }
        }
    '''


import unittest
from faker import Faker
from wivi_graph_client_py.client import GraphQL_Client
from datetime import datetime

client = GraphQL_Client("http://localhost:8092/graphql")

class TestCreateNetworkStats(unittest.TestCase):
    def setUp(self):
        self.fake = Faker()
        self.network_stats = {
            "errorMessages": self.fake.random_int(),
            "longMessageParts": self.fake.random_int(),
            "matchedMessages": self.fake.random_int(),
            "maxTime":  datetime.utcnow().isoformat(), 
            "minTime":  datetime.utcnow().isoformat(),
            "name": self.fake.word(),
            "rate": self.fake.random_int(),
            "totalMessages": self.fake.random_int(),
            "unmatchedMessages": self.fake.random_int(),
            "uploadId": self.fake.random_int(),
            "vehicleId": self.fake.random_int()
        }

    def test_basic(self):
        self.setUp()
        response = client.create_network_stats({"input":self.network_stats})
        results = response.get('data', {}).get('createNetworkStats', [])
        
        self.assertIsInstance(results, dict)
        self.assertIn("name", results)
        self.assertIn("vehicleId", results)
        self.assertIn("uploadId", results)
        self.assertIn("totalMessages", results)
        self.assertIn("matchedMessages", results)
        self.assertIn("unmatchedMessages", results)
        self.assertIn("errorMessages", results)
        self.assertIn("longMessageParts", results)
        self.assertIn("minTime", results)
        self.assertIn("maxTime", results)
        self.assertIn("rate", results)

        self.assertEqual(results["name"], self.network_stats["name"])
        self.assertEqual(results["vehicleId"], self.network_stats["vehicleId"])
        self.assertEqual(results["uploadId"], self.network_stats["uploadId"])
        self.assertEqual(results["totalMessages"], self.network_stats["totalMessages"])
        self.assertEqual(results["matchedMessages"], self.network_stats["matchedMessages"])
        self.assertEqual(results["unmatchedMessages"], self.network_stats["unmatchedMessages"])
        self.assertEqual(results["errorMessages"], self.network_stats["errorMessages"])
        self.assertEqual(results["longMessageParts"], self.network_stats["longMessageParts"])
        self.assertEqual(results["rate"], self.network_stats["rate"])

if __name__ == "__main__":
    unittest.main()



class Network_Query:
    get_network_query = """
        query GetNetworks($input: NetworkFilterInput) {
            network(input: $input) {
                id
                name
            }
        }
    """



import unittest
from faker import Faker
from wivi_graph_client_py.client import GraphQL_Client

class TestUpsertDeviceVersion(unittest.TestCase):
    async def asyncSetUp(self):
        self.fake = Faker()
        self.client = GraphQL_Client("http://localhost:8092/graphql")
        self.configurationDto = None
        configuration = {
            "vehicleId": self.fake.random_int(),
            "fleetId": self.fake.random_int(),
            "organizationId": self.fake.random_int(),
            "deviceId": self.fake.random_int()
        }
        response =  self.client.create_configuration({"input": configuration})
        self.configurationDto = response.get('data', {}).get('createConfiguration', {})

    async def test_create_device_version(self):
        await self.asyncSetUp()
        device_version = {
            "configurationId": self.configurationDto.get('id'),
            "data": [{
                "time": self.fake.date_time_this_decade(),
                "versions": [{
                    "name": self.fake.word(),
                    "version": self.fake.word()
                } for _ in range(3)]
            } for _ in range(3)]
        }
        response = self.client.upsert_version({"input": device_version})
        print(response)
        results = response.get('data', {}).get('upsertDeviceVersion', {})

        self.assertIsInstance(results, dict)

if __name__ == "__main__":
    unittest.main()



class Version_Query:
    get_version_query = """
        query GetVersions($input: VersionInfoFilter) {
            versionInfo(input: $input) {
                vehicleId
                versionInfo {
                    name
                    time
                    value
                }
            }
        }
    """

class Version_Mutation:
    upsert_version_mutation = '''
        mutation UpsertVersion($input: UpsertVersionInfoInput) {
            upsertVersionInfo(input: $input) {
                configurationId
            }
        }
    '''

    delete_version_mutation = '''
        mutation DeleteVersion($input: DeleteVersionInfoInput) {
            deleteVersionInfo(input: $input) {
                configurations
            }
        }
    '''


from setuptools import setup, find_packages

setup(
    name="wivi_graph_client_py",
    version="2.3.6",
    packages=find_packages(),
    install_requires=[
        "requests",
        "graphql-core",
    ],
    author="Haseeb Saif Ullah",
    author_email="hsaif@intrepidcs.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



class FailProcessingQuery:
    get_failed_processing_query = """
        query failedProcessing($input: FailedProcessingFilterInput) {
            failedProcessing(input: $input) {
                configuration {
                    id
                    deviceId
                    fleetId
                    organizationId
                    vehicleId
                }
                dbExists
                pipelineStatus
                uploadId
                xmlExists
            }
        }
    """

class FailProcessingMutation:
    upsert_failed_processing_mutation = '''
        mutation upsertFailedProcessing($input: UpsertFailedProcessingInput) {
            upsertFailedProcessing(input: $input) {
                configuration {
                    id
                    vehicleId
                    fleetId
                    organizationId
                    vehicleId
                }
                uploadId
                dbExists
                xmlExists
                pipelineStatus
            }
        }
    '''

    delete_failed_processing_mutation = '''
        mutation DeleteFailedProcessing($input: DeleteFailedProcessingInput) {
            deleteFailedProcessing(input: $input) {
                configurations
            }
        }
    '''


import unittest
from faker import Faker
from wivi_graph_client_py.client import GraphQL_Client

class TestCreateDeviceConnection(unittest.IsolatedAsyncioTestCase):
    async def setUp(self):
        self.fake = Faker()
        self.client = GraphQL_Client("http://localhost:8092/graphql")
        self.configurationDto = None

        # Generate fake configuration data
        configuration = {
            "vehicleId": self.fake.random_int(),
            "fleetId": self.fake.random_int(),
            "organizationId": self.fake.random_int(),
            "deviceId": self.fake.random_int()
        }
        
        # Create configuration and store the response
        response = self.client.create_configuration({"input": configuration})
        self.configurationDto = response.get('data', {}).get('createConfiguration', {})

    async def test_basic(self):
        await self.setUp()
        device_connection = {
            "endTime":  self.fake.date_time_this_decade().isoformat(),
            "startTime":  self.fake.date_time_this_decade().isoformat(),
            "time":  self.fake.date_time_this_decade().isoformat(),
            "bytesReceived": str(self.fake.random_int()),
            "bytesSent": str(self.fake.random_int()),
            "network": self.fake.ipv4(),
            "networkProvider": self.fake.ipv4(),
            "networkType": self.fake.ipv4(),
            "version": self.fake.ipv4(),
            "configuration":  {
                 "deviceId": self.configurationDto.get('deviceId'),
                "fleetId": self.configurationDto.get('fleetId'),
                "organizationId": self.configurationDto.get('organizationId'),
                "vehicleId": self.configurationDto.get('vehicleId')
            }
        }
        response = self.client.create_device_connection({"input":device_connection})
        results = response.get('data', {}).get('createDeviceConnection', {})
        self.assertIsInstance(results.get('bytesReceived'), str)
        self.assertIsInstance(results.get('bytesSent'), str)
        self.assertIsInstance(results.get('configuration').get('deviceId'), int)
        self.assertIsInstance(results.get('configuration').get('fleetId'), int)
        self.assertIsInstance(results.get('configuration').get('organizationId'), int)
        self.assertIsInstance(results.get('configuration').get('vehicleId'), int)
        self.assertIsInstance(results.get('endTime'), str)
        self.assertIsInstance(results.get('time'), str)
        self.assertIsInstance(results.get('version'), str)
        self.assertIsInstance(results.get('startTime'), str)

if __name__ == "__main__":
    unittest.main()



import unittest
from faker import Faker
from wivi_graph_client_py.client import GraphQL_Client

client = GraphQL_Client("http://localhost:8092/graphql")

class TestCreateConfiguration(unittest.TestCase):
    def setUp(self):
        self.fake = Faker()

    def test_simple(self):
        configuration = {
            "vehicleId": self.fake.random_int(),
            "fleetId": self.fake.random_int(),
            "organizationId": self.fake.random_int(),
            "deviceId": self.fake.random_int()
        }
        created_config = client.create_configuration({"input":configuration})
        upserted_data = created_config.get('data', {}).get('createConfiguration', {})
        self.assertIsInstance(upserted_data, dict)
        self.assertIn("id", upserted_data)
        self.assertEqual(upserted_data["vehicleId"], configuration["vehicleId"])
        self.assertEqual(upserted_data["fleetId"], configuration["fleetId"])
        self.assertEqual(upserted_data["organizationId"], configuration["organizationId"])
        self.assertEqual(upserted_data["deviceId"], configuration["deviceId"])

    def test_idempotent(self):
        configuration = {
            "vehicleId": self.fake.random_int(),
            "fleetId": self.fake.random_int(),
            "organizationId": self.fake.random_int(),
            "deviceId": self.fake.random_int()
        }

        created_config = client.create_configuration({"input":configuration})
        upserted_data = created_config.get('data', {}).get('createConfiguration', {})
        created_config2 = client.create_configuration({"input":configuration})
        upserted_data2 = created_config2.get('data', {}).get('createConfiguration', {})

        self.assertIsInstance(upserted_data, dict)
        self.assertIsInstance(upserted_data2, dict)
        self.assertIn("id", upserted_data)
        self.assertIn("id", upserted_data2)
        self.assertEqual(upserted_data["id"], upserted_data2["id"])

    def test_error_missing_vehicle_id(self):
        configuration = {
            "fleetId": self.fake.random_int(),
            "organizationId": self.fake.random_int(),
            "deviceId": self.fake.random_int()
        }

        try:
            response = client.create_configuration({"input": configuration})
            if response.get('errors'):
                error_message = response['errors'][0]['message']
                self.assertIn("Field \"vehicleId\" of required type \"Int!\" was not provided.", error_message)
            else:
                self.fail("Expected exception not raised")
        except Exception as e:
            self.assertIsInstance(e, AssertionError)
if __name__ == "__main__":
    unittest.main()



import unittest
from datetime import datetime

from wivi_graph_client_py.client import GraphQL_Client

client = GraphQL_Client("http://0.0.0.0:8092/graphql")

class TestUpsertDtcData(unittest.IsolatedAsyncioTestCase):
    async def setUp(self):
        self.configuration = {
            "input": {
                "deviceId": 1,
                "fleetId": 1,
                "organizationId": 1,
                "vehicleId": 1
            }
        }
        self.messages = {
            "input": {
                "messages": [
                    {
                        "arbId": "67890",
                        "name": "example_name",
                        "networkName": "PS-011",
                        "ecuId": "example_network_name", 
                        "uploadId": 12345
                    }
                ]   
            }
        }
        self.configurationDto = client.create_configuration(self.configuration)
        self.msgDto = client.create_message(self.messages)
        
        self.dtc_data = {
            "dtcId": "ABC1",
            "value": "12345",
            "status": "active",
            "description": "2024-02-18T12:00:00Z",
            "time": datetime.now().isoformat(),
            "snapshot": [
                {"time": "2024-02-18T12:00:00Z", "bytes": "snapshot_bytes_example"}
            ],
            "extension": [
                {"time": "2024-02-18T12:00:00Z", "bytes": "snapshot_bytes_example"}
            ]
        }
        
        self.dtc = {
            "input": {
                "configurationId": self.configurationDto['data']['createConfiguration']['id'],
                "messageId": self.msgDto['data']['createMessage'][0]['id'],
                "uploadId": 12345,
                "messageDate": datetime.now().isoformat(),
                "data": [self.dtc_data]
            }
        }

        self.dtc2 = self.dtc.copy()
        self.dtc2["input"]["data"][0]["dtcId"] = "ABC12"

        self.dtc_multiple = self.dtc.copy()
        self.dtc_multiple["input"]["data"].extend([
            {"dtcId": "ABC1234", **self.dtc_data},
            {"dtcId": "ABC12345", **self.dtc_data}
        ])

    async def test_create_dtc(self):
        await self.setUp()
        result = client.create_dtc(self.dtc)
        self.assertIsInstance(result, dict)

    async def test_prevent_duplicate_dtc_insertion(self):
        await self.setUp()
        result = client.create_dtc(self.dtc)
        result2 = client.create_dtc(self.dtc2)
        self.assertIn('data', result2)
        expected_keys = ['upsertDtcData']
        self.assertTrue(all(key in result2['data'] for key in expected_keys))

    async def test_create_multiple_bytes_for_extension_in_dtc(self):
        await self.setUp()
        result = client.create_dtc(self.dtc_multiple)
        self.assertIsInstance(result, dict)

    async def test_create_multiple_bytes_for_snapshot_in_dtc(self):
        await self.setUp()
        result = client.create_dtc(self.dtc_multiple)
        self.assertIsInstance(result, dict)

    async def test_create_multiple_dtc_values(self):
        await self.setUp()
        result = client.create_dtc(self.dtc2)
        self.assertIsInstance(result, dict)

    async def test_create_multiple_dtc_time_series_values(self):
        await self.setUp()
        result = client.create_dtc(self.dtc_multiple)
        self.assertIsInstance(result, dict)

if __name__ == "__main__":
    unittest.main()



class Device_Connections_Query:
    get_device_connection_query = """
        query deviceConnection($input: DeviceConnectionFilterInput) {
            deviceConnection(input: $input) {
                configuration {
                    deviceId
                    vehicleId
                    organizationId
                    fleetId
                }
            }
        }
    """


class Device_Connections_Mutation:

    upsert_device_connection_mutation = '''
        mutation createDeviceConnection($input: CreateDeviceConnectionInput) {
            createDeviceConnection(input: $input) {
                configuration {
                    vehicleId
                    fleetId
                    organizationId
                    deviceId
                }
                bytesReceived
                bytesSent
                networkProvider
                network
                networkType
                version
                startTime
                endTime
                time
            }
        }
    '''

    delete_device_connection_mutation = '''
        mutation DeleteDeviceConnection($input: DeleteDeviceConnectionInput) {
            deleteDeviceConnection(input: $input) {
                DeviceConnection
            }
        }
    '''



class Message_Query:
    get_message_query = """
        query message($input: MessageFilterInput) {
            message(input: $input) {
                id
                arbId
                name
                networkName
                ecuId
                ecuName
                fileId
            }
        }
    """

class Message_Mutation:
    create_message_mutation = """
        mutation createMessage($input: CreateMessageInput!) {
            createMessage(input: $input) {
                id
                arbId
                name
                networkName
                ecuId
                ecuName
                fileId
            }
        }
    """



import requests
from graphql import parse, print_ast
from .configuration import Configuration_Mutation
from .configuration import Configuration_Query
from .device_info import Device_Info_Mutation
from .device_info import Device_Info_Query
from .device_connection import Device_Connections_Mutation
from .device_connection import Device_Connections_Query

from .device_version import Device_Version_Query
from .device_version import Device_Version_Mutation
from .device_status import Device_Status_Mutation
from .device_status import Device_Status_Query
from .dtc import Dtc_Query
from .dtc import Dtc_Mutation
from .ecu import Ecu_Query
from .formula import Formula_Mutation
from .formula import Formula_Query
from .gps import GPS_Mutation
from .gps import GPS_Query
from .message import Message_Mutation
from .message import Message_Query
from .network_stats import Network_Stats_Mutation
from .network_stats import Network_Stats_Query
from .network import Network_Query
from .signal import Signals_Query
from .signal import Signals_Mutation
from .version import Version_Mutation
from .version import Version_Query
from .fail_processing import FailProcessingMutation
from .fail_processing import FailProcessingQuery

from requests.exceptions import RequestException
import time
import sys

class GraphQL_Client:
    def __init__(self, endpoint, max_retries, retry_delay):
        self.endpoint = endpoint
        self.max_retries = max_retries
        self.retry_delay = retry_delay 

    import requests

    def execute(self, query, variables=None):
    # Ensure at least one attempt is made even if self.max_retries is 0
        retries = self.max_retries + 1
        
        for attempt in range(1, retries + 1):
            try:
                request_data = {"query": print_ast(parse(query)), "variables": variables}
                response = requests.post(self.endpoint, json=request_data)
                
                if not response.text:
                    print("Empty response received.")
                    return {"data": None, "errors": "Empty response"}
                
                try:
                    response_data = response.json()
                except ValueError as e:
                    print("Failed to decode JSON:", e)
                    return {"data": None, "errors": "Invalid JSON response"}
                
                if "errors" in response_data:
                    print("GraphQL request had errors:", response_data["errors"])
                    return {"data": None, "errors": response_data["errors"]}
                
                return {"data": response_data["data"]}
            
            except RequestException as e:
                if attempt == retries:
                    print(f"Failed to connect after {retries-1} attempts. Last error: {str(e)}")
                    sys.stdout.flush()  # Force flush
                    raise RuntimeError(f"Connection failed after {retries-1} retries: {e}")
                
                print(f"Connection attempt {attempt} failed. Retrying in {self.retry_delay} seconds...")
                sys.stdout.flush()  # Force flush
                time.sleep(self.retry_delay)


    # Configuration Functions:
    def create_configuration(self, variables=None):
        mutation = Configuration_Mutation.create_configuration_mutation
        return self.execute(mutation, variables)

    def get_configuration(self, variables=None):
        query = Configuration_Query.get_configuration_query
        return self.execute(query, variables)

    # Device info Functions:
    # def create_device_status(self, variables=None):
    #     mutation = Device_Info_Mutation.create_device_info_mutation
    #     return self.execute(mutation, variables)

    # def delete_device_info(self, variables=None):
    #     mutation = Device_Info_Mutation.delete_device_info_mutation
    #     return self.execute(mutation, variables)

    # def get_device_info(self, variables=None):
    #     query = Device_Info_Query.get_device_info_query
    #     return self.execute(query, variables)
    # Device Connection Functions
    def create_device_connection(self, variables=None):
        mutation = Device_Connections_Mutation.upsert_device_connection_mutation
        return self.execute(mutation, variables)
    def delete_device_connection(self, variables=None):
        mutation = Device_Connections_Mutation.delete_device_connection_mutation
        return self.execute(mutation, variables)
    def get_device_connection(self, variables=None):
        query = Device_Connections_Query.get_device_connection_query
        return self.execute(query, variables)
    
    # Device status Functions:
    def create_device_status(self, variables=None):
        mutation = Device_Status_Mutation.create_device_status_mutation
        return self.execute(mutation, variables)

    def delete_device_status(self, variables=None):
        mutation = Device_Status_Mutation.delete_device_status_mutation
        return self.execute(mutation, variables)

    def get_device_status(self, variables=None):
        query = Device_Status_Query.get_device_status_query
        return self.execute(query, variables)
    # Device version Functions:
    def create_device_version(self, variables=None):
        mutation = Device_Version_Mutation.upsert_device_version_mutation
        return self.execute(mutation, variables)

    def delete_device_version(self, variables=None):
        mutation = Device_Version_Mutation.delete_device_version_mutation
        return self.execute(mutation, variables)

    def get_device_version(self, variables=None):
        query = Device_Version_Query.get_device_version_query
        return self.execute(query, variables)
    # DTC Functions:
    def create_dtc(self, variables=None):
        mutation = Dtc_Mutation.upsert_dtc_mutation
        return self.execute(mutation, variables)

    def delete_dtc(self, variables=None):
        mutation = Dtc_Mutation.delete_dtc_mutation
        return self.execute(mutation, variables)

    def get_dtc(self, variables=None):
        query = Dtc_Query.get_dtc_query
        return self.execute(query, variables)

    # ECU Functions:
    def get_ecu(self, variables=None):
        query = Ecu_Query.get_ecu_query
        return self.execute(query, variables)

    # Formula Functions:
    def upsert_formula(self, variables=None):
        mutation = Formula_Mutation.upsert_formula_mutation
        return self.execute(mutation, variables)

    def upsert_formula_constant(self, variables=None):
        mutation = Formula_Mutation.upsert_formula_constant_mutation
        return self.execute(mutation, variables)

    def load_formula(self, variables=None):
        query = Formula_Query.load_formula_query
        return self.execute(query, variables)

    def calculate_formula(self, variables=None):
        query = Formula_Query.calculate_formula_query
        return self.execute(query, variables)

    # GPS Functions
    def upsert_gps(self, variables=None):
        mutation = GPS_Mutation.upsert_gps_mutation
        return self.execute(mutation, variables)

    def delete_gps(self, variables=None):
        mutation = GPS_Mutation.delete_gps_mutation
        return self.execute(mutation, variables)

    def get_gps(self, variables=None):
        query = GPS_Query.get_gps_query
        return self.execute(query, variables)

    # Message Functions
    def create_message(self, variables=None):
        mutation = Message_Mutation.create_message_mutation
        return self.execute(mutation, variables)

    def get_message(self, variables=None):
        query = Message_Query.get_message_query
        return self.execute(query, variables)

    # Network Stats Functions
    def create_network_stats(self, variables=None):
        mutation = Network_Stats_Mutation.create_network_stats_mutation
        return self.execute(mutation, variables)

    def get_network_stats(self, variables=None):
        query = Network_Stats_Query.get_network_stats_query
        return self.execute(query, variables)

    # Network Functions
    def get_network(self, variables=None):
        query = Network_Query.get_network_query
        return self.execute(query, variables)

    # Signal Functions
    def upsert_signal_data(self, variables=None):
        mutation = Signals_Mutation.upsert_signal_data_mutation
        return self.execute(mutation, variables)

    def delete_signal_data(self, variables=None):
        mutation = Signals_Mutation.delete_signal_data_mutation
        return self.execute(mutation, variables)

    def get_signals(self, variables=None):
        query = Signals_Query.get_signals_query
        return self.execute(query, variables)

    def get_signal_data(self, variables=None):
        query = Signals_Query.get_signals_data_query
        return self.execute(query, variables)

    # Version Functions
    def upsert_version(self, variables=None):
        mutation = Version_Mutation.upsert_version_mutation
        return self.execute(mutation, variables)

    def delete_version(self, variables=None):
        mutation = Version_Mutation.delete_version_mutation
        return self.execute(mutation, variables)

    def get_version(self, variables=None):
        query = Version_Query.get_version_query
        return self.execute(query, variables)
    
    #Fail Processing Function
    def upsert_failed_processing(self, variables=None):
        mutation = FailProcessingMutation.upsert_failed_processing_mutation
        return self.execute(mutation, variables)

    def delete_failed_processing(self, variables=None):
        mutation = FailProcessingMutation.delete_failed_processing_mutation
        return self.execute(mutation, variables)

    def get_failed_processing(self, variables=None):
        query = FailProcessingQuery.get_failed_processing_query
        return self.execute(query, variables)
